nsi.granulate.tests.testGranulateOffice

Package nsi :: Package granulate :: Package tests :: Module testGranulateOffice |
[hide private]
[frames] | no frames]

# Module testGranulateOffice

source code

Author: Ronaldo Amaral Santos <ronaldinho.as@gmail.com>

Classes | [hide private]
| TestGranulateOffice

Variables | [hide private]
| filePath = ``'``/usr/lib/python2.4/site-packages/granulate-0.1dev-``...``
| filedata = ``'``PK\x03\x04\x14\x00\x00\x00\x00\x00n\xbfn8^\xc62\x0``...``

Variables Details | [hide private]

  ### filePath Value:
      '/usr/lib/python2.4/site-packages/granulate-0.1dev-py2.4.egg/nsi/granu
      late/tests/data/test.odt'

  ### filedata Value:
      '''PK\x03\x04\x14\x00\x00\x00\x00\x00n\xbfn8^\xc62\x0c\'\x00\x00\x00\'
      \x00\x00\x00\x08\x00\x00\x00mimetypeapplication/vnd.oasis.opendocument
      .textPK\x03\x04\x14\x00\x00\x00\x00\x00n\xbfn8\x00\x00\x00\x00\x00\x00
      \x00\x00\x00\x00\x00\x00\x1a\x00\x00\x00Configurations2/statusbar/PK\x
      03\x04\x14\x00\x08\x00\x08\x00n\xbfn8\x00\x00\x00\x00\x00\x00\x00\x00\
      x00\x00\x00\x00\'\x00\x00\x00Configurations2/accelerator/current.xml\x
      03\x00PK\x07\x08\x00\x00\x00\x00\x02\x00\x00\x00\x00\x00\x00\x00PK\x03
      \x04\x14\x00\x00\x00\x00\x00n\xbfn8\x00\x00\x00\x00\x00\x00\x00\x00\x0
      ...